# Example Package

## Exceptions and status code

- MissingMetricInfoException: 541
- InvalidAccessTokenException: 542
- GoogleApiException: 543
- MissingAccountIdException: 544
- MissingActionException: 545
- MissingChannelException: 546
- QueryDBRequestException: 547
- FacebookApiException: 548
- TikTokApiException: 549

## Example Import
`from playfilm_shared.exceptions import MissingMetricInfoException`
